Shutdown - GSI Online DNA
=================

Requirements
------------

- GSI Online capable digital level

Examples
--------

.. code-block:: shell
    :caption: Shutting down the instrument

    iman shutdown gsidna COM1

Usage
-----

.. click:: instrumentman.control:cli_shutdown_gsidna
    :prog: iman shutdown gsidna
